package com.openeggbert.jdotnet.JDotNet.Properties;

import lombok.AllArgsConstructor;
import lombok.NoArgsConstructor;

/**
 * An abstract base class for implementing property-like behavior.
 *
 * This class provides a protected field "value" that can be used by subclasses
 * to manage the state of the property. The type of the property value is defined
 * by the generic type parameter <T>.
 *
 * Subclasses can provide specific implementations of read-only, write-only,
 * or read-write properties by exposing appropriate methods for access or modification
 * of the "value" field.
 *
 * @param <T> the type of the property's value
 */
@AllArgsConstructor
@NoArgsConstructor
public abstract class AbstractPropertyImpl<T> {
    /**
     * The value stored by the property.
     *
     * This field is protected to allow subclasses to directly manage
     * the property's value, while providing flexibility for implementing
     * specific behaviors such as read-only, write-only, or read-write access.
     *
     * @param <T> the type of the property's value
     */
    protected T value;
}
