package com.openeggbert.jdotnet.JDotNet.Properties;

/**
 * Represents a read-only property for a value of type T.
 *
 * This interface defines a single method to retrieve the property value,
 * ensuring that implementing classes provide read access while prohibiting
 * modification of the value it holds.
 *
 * @param <T> the type of the property's value
 */
@FunctionalInterface
public interface IReadOnlyProperty<T> {
    /**
     * Retrieves the value of the property.
     *
     * @return the current value of the property
     */
    T get();
}
