package com.openeggbert.jdotnet.JDotNet.Properties;

/**
 * Represents a write-only property for a value of type T.
 *
 * This interface defines a single method to set the property value,
 * ensuring that implementing classes provide write access while prohibiting
 * retrieval of the value it holds.
 *
 * @param <T> the type of the property's value
 */
@FunctionalInterface
public interface IWriteOnlyProperty<T> {
    /**
     * Sets the value for the property.
     *
     * @param value the value to set for the property
     */
    void set(T value);
}
