package com.openeggbert.jdotnet.JDotNet.Properties;

import lombok.AllArgsConstructor;
import lombok.NoArgsConstructor;

/**
 * A concrete implementation of a read-only property for a value of type T.
 *
 * This class extends AbstractPropertyImpl to inherit its protected "value" field
 * for storing the state of the property. As a read-only property, it implements
 * the IReadOnlyProperty interface, providing only a getter method to retrieve
 * the current value of the property while prohibiting any modifications.
 *
 * @param <T> the type of the property's value
 */

@AllArgsConstructor
@NoArgsConstructor
public class ReadOnlyPropertyImpl<T> extends AbstractPropertyImpl<T> implements IReadOnlyProperty<T> {

    /**
     * Retrieves the current value of the property.
     *
     * @return the current value of the property
     */
    @Override
    public T get() {
        return value;
    }
}
