package com.openeggbert.jdotnet.JDotNet.Properties;

import lombok.AllArgsConstructor;
import lombok.NoArgsConstructor;

/**
 * A concrete implementation of a write-only property for a value of type T.
 *
 * This class extends AbstractPropertyImpl, leveraging its protected "value" field
 * to store the property's data. It implements the IWriteOnlyProperty interface,
 * providing a setter method to modify the property's value while prohibiting
 * access to retrieve it.
 *
 * @param <T> the type of the property's value
 */

@AllArgsConstructor
@NoArgsConstructor
public class WriteOnlyPropertyImpl<T> extends AbstractPropertyImpl<T> implements IWriteOnlyProperty<T> {

    /**
     * Sets the value for the property.
     *
     * @param valueIn the value to set for the property
     */
    @Override
    public void set(T valueIn) {
        this.value = valueIn;
    }
}
