/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/Classes/Class.java to edit this template
 */
package com.openeggbert.jdotnet.System;

import com.openeggbert.jdotnet.JDotNet.AdditionalClassForDotNetEmulation;
import java.util.ArrayList;
import java.util.List;

/**
 * An implementation of the EventHandler interface, responsible for managing
 * event listeners and invoking them when an event occurs.
 *
 * @param <T> The type of event arguments that will be passed to the listeners.
 *
 * This class simulates the behavior of C# event handling.
 * It allows adding and removing event listeners, as well as invoking them
 * with the provided event arguments.
 */
@AdditionalClassForDotNetEmulation
public class EventHandlerImpl<T> implements EventHandler<T> {

    private final List<EventListener<T>> list = new ArrayList<>();
    
    @Override
    public void addEventListener(EventListener<T> listener) {
        list.add(listener);
    }

    @Override
    public void removeEventListener(EventListener<T> listener) {
        list.remove(listener);
    }

    @Override
    public void invoke(T eventArgs) {
        for(EventListener<T> e : list) {
            e.onEventHappened(eventArgs);
        }
    }
    
}
